@@ -224,9 +224,6 @@ BaremetalGroup = [
                min=0,
                help="Ironic adjusted disk size to use in the standalone tests "
                     "as instance_info/root_gb value."),
-    cfg.IntOpt('available_nodes', min=0, default=None,
-               help="The number of baremetal hosts available to use for "
-                    "the tests."),
     cfg.BoolOpt('partition_netboot',
                 default=True,
                 help="Treat partition images as netbooted as opposed to "
