@@ -23,6 +23,11 @@ from tempest.lib.common import rest_client
 # separate processes so global variables are not shared among them.
 BAREMETAL_MICROVERSION = None
 
+# Interfaces that can be set via the baremetal client and by logic in scenario
+# managers.
+SUPPORTED_INTERFACES = ['bios', 'deploy', 'rescue', 'boot', 'raid',
+                        'management', 'power', 'inspect']
+
 
 def set_baremetal_api_microversion(baremetal_microversion):
     global BAREMETAL_MICROVERSION
@@ -63,9 +68,33 @@ class BaremetalClient(rest_client.RestClient):
     def get_headers(self):
         headers = super(BaremetalClient, self).get_headers()
         if BAREMETAL_MICROVERSION:
+            # NOTE(TheJulia): This is not great, because it can blind a test
+            # to the actual version supported.
             headers[self.api_microversion_header_name] = BAREMETAL_MICROVERSION
         return headers
 
+    def get_raw_headers(self):
+        """A proper get headers without guessing the microversion."""
+        return super(BaremetalClient, self).get_headers()
+
+    def get_min_max_api_microversions(self):
+        """Returns a tuple of minimum and remote microversions."""
+        if '/v1' in self.base_url:
+            root_uri = '/'
+        else:
+            # NOTE(dtantsur): we should just use / here but due to a bug in
+            # Ironic, / does not contain the microversion headers. See
+            # https://bugs.launchpad.net/ironic/+bug/2079023
+            root_uri = '/v1'
+        _, resp_body = self._show_request(None, uri=root_uri)
+        try:
+            version = resp_body['default_version']
+        except KeyError:
+            version = resp_body['version']
+        api_min = version.get('min_version')
+        api_max = version.get('version')
+        return (api_min, api_max)
+
     def request(self, *args, **kwargs):
         resp, resp_body = super(BaremetalClient, self).request(*args, **kwargs)
         latest_microversion = api_version_utils.LATEST_MICROVERSION
